public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r9-8495] Rename 'libgomp.oacc-c-c++-common/static-dynamic-lifetimes-*' to 'libgomp.oacc-c-c++-common/structur
@ 2020-04-13  7:00 Thomas Schwinge
  0 siblings, 0 replies; only message in thread
From: Thomas Schwinge @ 2020-04-13  7:00 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:a99a8431e670a6c0ac861d738249ff4d94d6552e

commit r9-8495-ga99a8431e670a6c0ac861d738249ff4d94d6552e
Author: Thomas Schwinge <thomas@codesourcery.com>
Date:   Mon Apr 13 08:56:03 2020 +0200

    Rename 'libgomp.oacc-c-c++-common/static-dynamic-lifetimes-*' to 'libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-*' [PR92843]
    
    Fix-up for commit be9862dd96945772ae0692bc95b37ec6dbcabda0 "Test cases for
    mixed structured/dynamic data lifetimes with OpenACC [PR92843]": it's
    "structured", not "static" data lifetimes/reference counters.
    
            libgomp/
            PR libgomp/92843
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8-lib.c:
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8-lib.c:
            ... this.
            * testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8.c::
            Rename to...
            * testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8.c:
            ... this.
    
    (cherry picked from commit af4c92573dc462a17a6c345756889d28054ed591)

Diff:
---
 libgomp/ChangeLog                                  | 68 ++++++++++++++++++++++
 .../static-dynamic-lifetimes-5-lib.c               |  3 -
 .../static-dynamic-lifetimes-6-lib.c               |  3 -
 .../static-dynamic-lifetimes-7-lib.c               |  3 -
 .../static-dynamic-lifetimes-8-lib.c               |  3 -
 ...-lib.c => structured-dynamic-lifetimes-1-lib.c} |  2 +-
 ...etimes-1.c => structured-dynamic-lifetimes-1.c} |  5 +-
 ...-lib.c => structured-dynamic-lifetimes-2-lib.c} |  2 +-
 ...etimes-2.c => structured-dynamic-lifetimes-2.c} |  2 +-
 ...-lib.c => structured-dynamic-lifetimes-3-lib.c} |  2 +-
 ...etimes-3.c => structured-dynamic-lifetimes-3.c} |  2 +-
 ...-lib.c => structured-dynamic-lifetimes-4-lib.c} |  2 +-
 ...etimes-4.c => structured-dynamic-lifetimes-4.c} |  0
 .../structured-dynamic-lifetimes-5-lib.c           |  3 +
 ...etimes-5.c => structured-dynamic-lifetimes-5.c} |  0
 .../structured-dynamic-lifetimes-6-lib.c           |  3 +
 ...etimes-6.c => structured-dynamic-lifetimes-6.c} |  3 +-
 .../structured-dynamic-lifetimes-7-lib.c           |  3 +
 ...etimes-7.c => structured-dynamic-lifetimes-7.c} |  6 +-
 .../structured-dynamic-lifetimes-8-lib.c           |  3 +
 ...etimes-8.c => structured-dynamic-lifetimes-8.c} |  0
 21 files changed, 95 insertions(+), 23 deletions(-)

diff --git a/libgomp/ChangeLog b/libgomp/ChangeLog
index 39308ecbc03..2926096bb7c 100644
--- a/libgomp/ChangeLog
+++ b/libgomp/ChangeLog
@@ -1,3 +1,71 @@
+2020-04-13  Thomas Schwinge  <thomas@codesourcery.com>
+
+	PR libgomp/92843
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8-lib.c:
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8-lib.c:
+	... this.
+	* testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8.c::
+	Rename to...
+	* testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8.c:
+	... this.
+
 2020-04-10  Julian Brown  <julian@codesourcery.com>
 	    Thomas Schwinge  <thomas@codesourcery.com>
 
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5-lib.c
deleted file mode 100644
index 77703122ad6..00000000000
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5-lib.c
+++ /dev/null
@@ -1,3 +0,0 @@
-/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
-/* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-5.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6-lib.c
deleted file mode 100644
index 4a87dd72525..00000000000
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6-lib.c
+++ /dev/null
@@ -1,3 +0,0 @@
-/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
-/* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-6.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7-lib.c
deleted file mode 100644
index 8ccbb126933..00000000000
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7-lib.c
+++ /dev/null
@@ -1,3 +0,0 @@
-/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
-/* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-7.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8-lib.c
deleted file mode 100644
index f3104cbd035..00000000000
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8-lib.c
+++ /dev/null
@@ -1,3 +0,0 @@
-/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
-/* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-8.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1-lib.c
similarity index 70%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1-lib.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1-lib.c
index 23c20d4fab7..8fa87777f1a 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1-lib.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1-lib.c
@@ -1,3 +1,3 @@
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 /* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-1.c"
+#include "structured-dynamic-lifetimes-1.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1.c
similarity index 95%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1.c
index a743660f53e..0d6b4159ad0 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-1.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-1.c
@@ -1,4 +1,4 @@
-/* Test transitioning of data lifetimes between static and dynamic.  */
+/* Test transitioning of data lifetimes between structured and dynamic.  */
 
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 
@@ -69,7 +69,8 @@ f2 (void)
 #else
 #pragma acc exit data copyout(block1[0:SIZE])
 #endif
-    /* This should stay present until the end of the static data lifetime.  */
+    /* This should stay present until the end of the structured data
+       lifetime.  */
     assert (acc_is_present (block1, SIZE));
   }
 
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2-lib.c
similarity index 70%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3-lib.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2-lib.c
index d9e76c600f0..365df8d7f7d 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3-lib.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2-lib.c
@@ -1,3 +1,3 @@
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 /* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-3.c"
+#include "structured-dynamic-lifetimes-2.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2.c
similarity index 98%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2.c
index d3c6f5192d8..726942c76fd 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-2.c
@@ -1,4 +1,4 @@
-/* Test nested dynamic/static data mappings.  */
+/* Test nested dynamic/structured data mappings.  */
 
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3-lib.c
similarity index 70%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2-lib.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3-lib.c
index 84f41a49dfd..469b35b76f1 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-2-lib.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3-lib.c
@@ -1,3 +1,3 @@
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 /* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-2.c"
+#include "structured-dynamic-lifetimes-3.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3.c
similarity index 97%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3.c
index 59501864398..c13f3c56584 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-3.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-3.c
@@ -1,4 +1,4 @@
-/* Test nested dynamic/static data mappings (multiple blocks on data
+/* Test nested dynamic/structured data mappings (multiple blocks on data
    regions).  */
 
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4-lib.c
similarity index 70%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4-lib.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4-lib.c
index e3c1bfb473d..8e88b97b2ce 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4-lib.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4-lib.c
@@ -1,3 +1,3 @@
 /* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
 /* { dg-additional-options "-DOPENACC_API" } */
-#include "static-dynamic-lifetimes-4.c"
+#include "structured-dynamic-lifetimes-4.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4.c
similarity index 100%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-4.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-4.c
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5-lib.c
new file mode 100644
index 00000000000..59ef5626bd0
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5-lib.c
@@ -0,0 +1,3 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+/* { dg-additional-options "-DOPENACC_API" } */
+#include "structured-dynamic-lifetimes-5.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5.c
similarity index 100%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-5.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-5.c
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6-lib.c
new file mode 100644
index 00000000000..0401f73966f
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6-lib.c
@@ -0,0 +1,3 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+/* { dg-additional-options "-DOPENACC_API" } */
+#include "structured-dynamic-lifetimes-6.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6.c
similarity index 90%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6.c
index 3e5c4d7ea11..9250b4af3ed 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-6.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-6.c
@@ -27,7 +27,8 @@ main (int argc, char *argv[])
 #else
 #pragma acc exit data copyout(block1[0:SIZE], block2[0:SIZE])
 #endif
-    /* These should stay present until the end of the static data lifetime.  */
+    /* These should stay present until the end of the structured data
+       lifetime.  */
     assert (acc_is_present (block1, SIZE));
     assert (acc_is_present (block2, SIZE));
   }
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7-lib.c
new file mode 100644
index 00000000000..07caefbd082
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7-lib.c
@@ -0,0 +1,3 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+/* { dg-additional-options "-DOPENACC_API" } */
+#include "structured-dynamic-lifetimes-7.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8-lib.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8-lib.c
new file mode 100644
index 00000000000..1c2479ad96f
--- /dev/null
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8-lib.c
@@ -0,0 +1,3 @@
+/* { dg-skip-if "" { *-*-* } { "-DACC_MEM_SHARED=1" } } */
+/* { dg-additional-options "-DOPENACC_API" } */
+#include "structured-dynamic-lifetimes-8.c"
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7.c
similarity index 82%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7.c
index 2735d6fa0eb..52e8d4c9959 100644
--- a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-7.c
+++ b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-7.c
@@ -21,13 +21,15 @@ main (int argc, char *argv[])
 #pragma acc data copy(block1[0:SIZE], block2[0:SIZE])
   {
 /* We can't attach the dynamic data mapping's (block1) target_mem_desc to the
-   enclosing static data region here, because that region maps block2 also.  */
+   enclosing structured data region here, because that region maps block2
+   also.  */
 #ifdef OPENACC_API
     acc_copyout (block1, SIZE);
 #else
 #pragma acc exit data copyout(block1[0:SIZE])
 #endif
-    /* These should stay present until the end of the static data lifetime.  */
+    /* These should stay present until the end of the structured data
+       lifetime.  */
     assert (acc_is_present (block1, SIZE));
     assert (acc_is_present (block2, SIZE));
   }
diff --git a/libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8.c b/libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8.c
similarity index 100%
rename from libgomp/testsuite/libgomp.oacc-c-c++-common/static-dynamic-lifetimes-8.c
rename to libgomp/testsuite/libgomp.oacc-c-c++-common/structured-dynamic-lifetimes-8.c


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2020-04-13  7:00 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-04-13  7:00 [gcc r9-8495] Rename 'libgomp.oacc-c-c++-common/static-dynamic-lifetimes-*' to 'libgomp.oacc-c-c++-common/structur Thomas Schwinge

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).